********************************************************************************
* Identifying the date of the first significant employment          		   *
*      							                                               *    
* Steffen Schindler, 16/04/2025                               				   *
********************************************************************************

clear
set more off
cap log close

version 16.1
use "${savedta}\month_episodes.dta"
merge m:m ID_t splink using "${savedta}\SC6_spEmp_D_${SUF}", nogen keep(match master)
merge m:1 ID_t using "${savedta}\basicinfo.dta", nogen keep(match master) keepusing(birthdate)

* mark IDs with spells containing employment episodes
egen temp=anymatch(sptype), values(26)
bys ID_t: egen everemp=max(temp)
drop temp 
lab var everemp "person with employment spell"

* mark IDs with months containing employment episodes without parallel states in education, training, military service, parental leave
egen temp1_a=anymatch(sptype), values(22 23 24 25 27 29) // gap, further edu, internship can be parallel spelltypes
bys ID_t month: egen temp1_b=max(temp1_a)
egen temp2_a=anymatch(sptype), values(26)
bys ID_t month: egen temp2_b=max(temp2_a)
gen pureemp=1 if temp1_b!=1 & temp2_b==1 
drop temp1_* temp2_* 

* gen duration of uninterrupted employment without parallel states in education, training, military service, parental leave
sort ID_t month monthnr
gen empdurcount=pureemp
replace empdurcount=empdurcount[_n-1]+1 if sptype==26 & empdurcount[_n-1]>=1 & empdurcount<. & ID_t==ID_t[_n-1] & splink==splink[_n-1] 
bys ID_t splink: egen empdur=max(empdurcount)
sort ID_t month monthnr

* generate indicator of working hours
clonevar whc = ts23219_g1 // contractual weekly working hours
replace whc=20 if ts23218==2 & whc>=. // 20h if part-time
replace whc=40 if ts23218==1 & whc>=. // 40h if full-time
ren ts23223_g1 wha // actual working hours

* mark spells with at least 20h working time in a single job (version 1)
egen over20s=rowmax(whc wha)
gen test20s=over20s
replace over20s=0 if over20s<20
replace over20s=1 if over20s>=20 & over20s<.
replace over20s=.a if over20s>=. & sptype==26
lab var over20s "person has worked more than 20h in a single job"

* mark spells with at least 20h cumulative working time (version 2)
bys ID_t month: egen temp1=total(whc)
bys ID_t month: egen temp2=total(wha)
egen over20c=rowmax(temp1 temp2)
gen test20c=over20c
replace over20c=0 if over20c<20
replace over20c=1 if over20c>=20 & over20c<.
replace over20c=.a if over20c>=. & sptype==26
lab var over20c "person has worked more than 20h cumulatively"
drop temp* 
* test if version 1 and 2 make a difference
bys ID_t month: egen temps=max(over20s) 
bys ID_t month: egen tempc=max(over20c) 
gen diff=1 if temps!=tempc
tab diff if sptype==26 & monthnr==1,m // --> differences in 98,288 out of 4,926,904 months (1.99%) --> we will use version 2
drop diff temp*

* mark significant job
gen sigjob=0
replace sigjob=1 if pureemp==1 & over20c==1 & empdur>=12 & empdur<. // no parallel states, >20h cumulative working time, >=12 months in job 
bys ID_t: egen eversigjob=max(sigjob)
lab var eversigjob "person with significant job spell"

* identify date of first significant job
lab def datesigjob .a"never had significant job" .b"never employed"
bys ID_t sigjob: egen temp=min(month) if sigjob==1
bys ID_t: egen datesigjob1=min(temp) 
replace datesigjob1=.a if everemp==1 & eversigjob==0 & datesigjob1==.
replace datesigjob1=.b if everemp==0 & datesigjob1==.
lab val datesigjob1 datesigjob
lab var datesigjob1 "start date first significant job (months since 01/1960)"
format datesigjob1 %tm

* year of first significant job
gen yearsigjob1=floor(1960+(datesigjob1/12))
replace yearsigjob1=.a if everemp==1 & eversigjob==0 & yearsigjob1==.
replace yearsigjob1=.b if everemp==0 & yearsigjob1==.
lab val yearsigjob1 datesigjob
lab var yearsigjob1 "year first significant job"

* age of first significant job (in months)
gen agesigjob1m=datesigjob-birthdate
replace agesigjob1m=datesigjob if datesigjob>=.
lab def agesigjob .a"never had significant job" .b"never employed"
lab val agesigjob1m agesigjob
lab var agesigjob1m "start age first significant job (in months)"

* age of first significant job (in years)
gen agesigjob1y=agesigjob1m
replace agesigjob1y=floor(agesigjob1y/12) if agesigjob1y<.
lab val agesigjob1y agesigjob
lab var agesigjob1y "age first significant job (in years)"

* turn data into wide format and keep necessary variables
bys ID_t: keep if _n==1
keep ID_t everemp eversigjob datesigjob1 yearsigjob1 agesigjob1m agesigjob1y

* save data
save "${savedta}\date_employ1.dta", replace
exit
