********************************************************************************
* Recode educational degrees into information-by-age format           		   *
*      							                                               *    
* Steffen Schindler, 16/04/2025                               				   *
********************************************************************************

clear
set more off
cap log close

version 16.1

use ID_t month birthdate agem agey lowage migration_age schooldegree_cum schooldegree_add schoolgpa vocdegree_cum vocdegree_add using "${savedta}\educ_merge", clear


*** RECODE EDUCATION VARIABLES *************************************************

*** recode school-leaving degree variables

* update indicator if new school-leaving degree has been obtained into binary variable
replace schooldegree_add=.m if schooldegree_cum==.m & schooldegree_add!=1
replace schooldegree_add=0 if schooldegree_add==.
lab def schooldegree_add 0"no new degree obtained" 1"any new degree obtained" .m"case without any schooldegree information"
lab val schooldegree_add schooldegree_add

gen sd_add=0
replace sd_add=1 if ID_t==ID_t[_n-1] & schooldegree_cum>schooldegree_cum[_n-1] & schooldegree_cum<.
replace sd_add=.m if schooldegree_cum==.m
replace sd_add=1 if sd_add==0 & schooldegree_add==1 & inlist(schooldegree_cum,1,2,6,9,10,13,14,17,18,21,22) & schoolgpa!=. // multiple indeterminate degrees possible, adjust only if GPA non-missing

* generate variable indicating if most recent school-leaving degree has been obtained abroad
gen schooldegree_abroad=0
replace schooldegree_abroad=1 if inlist(schooldegree_cum,1,3,5,7,9,11,13,15,17,19,21,23)
replace schooldegree_abroad=.m if schooldegree_cum==.m
lab var schooldegree_abroad "most recent school-leaving degree obtained abroad"
lab def schooldegree_abroad 0 "in Germany" 1 "abroad" .m "case without any schooldegree information"
lab val schooldegree_abroad schooldegree_abroad
ta schooldegree_cum schooldegree_abroad,m 

* generate indicator of age at first school-leaving degree
gen temp1=agey if schooldegree_cum>0 & schooldegree_cum<.
bys ID_t: egen schooldegree_1_age=min(temp1)
replace schooldegree_1_age=.m if schooldegree_cum==.m
replace schooldegree_1_age=.l if schooldegree_1_age==.
lab var schooldegree_1_age "age first school-leaving degree"
lab def schooldegree_1_age .l "no degree obtained" .m "case without any schooldegree information" 
lab val schooldegree_1_age schooldegree_1_age
bys ID_t: gen n=_n
ta schooldegree_1_age if n==1,m
drop temp*

* expand schoolgpa to subsequent months and adjust variable sd_add indicating additional schooldegree
gen schoolgpa_cum=schoolgpa
replace schoolgpa_cum=schoolgpa_cum[_n-1] if  ID_t==ID_t[_n-1] & schoolgpa_cum==. & schoolgpa_cum[_n-1]!=. & schooldegree_cum==schooldegree_cum[_n-1]
replace schoolgpa_cum=.m if schooldegree_cum==0
replace sd_add=1 if sd_add==0 & schooldegree_add==1 & ID_t==ID_t[_n-1] & schoolgpa_cum!=0 & schoolgpa_cum<schoolgpa_cum[_n-1] & schoolgpa_cum<. // code as additional degree if same degree but better grade
replace schoolgpa_cum=schoolgpa_cum[_n-1] if ID_t==ID_t[_n-1] & schooldegree_cum==schooldegree_cum[_n-1] & schoolgpa_cum>schoolgpa_cum[_n-1] & schoolgpa_cum[_n-1]<. & sd_add==0 // adjust GPA if no new degree, but GPA getting worse
lab var schoolgpa_cum "GPA school-leaving degree"
lab val schoolgpa_cum schoolgpa

* drop original schooldegree_add variable and rename sd_add
drop schooldegree_add
ren sd_add schooldegree_add
lab val schooldegree_add schooldegree_add
lab var schooldegree_add "additional school-leaving degree obtained"


*** recode vocational degree variables

* recode indicator if new school-leaving degree has been obtained into binary variable
replace vocdegree_add=.m if vocdegree_cum==.m & vocdegree_add!=1
replace vocdegree_add=0 if vocdegree_add==.
lab def vocdegree_add 0"no new degree obtained" 1"any new degree obtained" .m"case without any vocdegree information"
lab val vocdegree_add vocdegree_add

* generate variable indicating if most recent vocational degree has been obtained abroad
gen vocdegree_abroad=0
replace vocdegree_abroad=1 if inlist(vocdegree_cum,1,3,5,7,9,11,13,15)
replace vocdegree_abroad=.m if vocdegree_cum==.m
lab var vocdegree_abroad "most recent vocational degree obtained abroad"
lab def vocdegree_abroad 0 "in Germany" 1 "abroad" .m "case without any vocdegree information"
lab val vocdegree_abroad vocdegree_abroad
ta vocdegree_cum vocdegree_abroad,m 

* generate indicator of age at first vocational degree
gen temp1=agey if vocdegree_cum>0 & vocdegree_cum<.
bys ID_t: egen vocdegree_1_age=min(temp1)
replace vocdegree_1_age=.m if vocdegree_cum==.m
replace vocdegree_1_age=.l if vocdegree_1_age==.
lab var vocdegree_1_age "age first vocational degree"
lab def vocdegree_1_age .l "no degree obtained" .m "case without any vodegree information" 
lab val vocdegree_1_age vocdegree_1_age
ta vocdegree_1_age if n==1,m
drop temp* n


*** TRANSFER DATA INTO INFORMATION-BY-AGE FORMAT *******************************

*** save data before changing format
compress
save "${savedta}\educ_age_long.dta", replace   

*** generate age variable indicating full years
gen agefy=floor(agey)
tab agefy,m // negative age values for 9 respondents

*** rename schooldegree_cum and vocdegree_cum and label copy
ren schooldegree_cum schooldegree
ren vocdegree_cum vocdegree
label copy schooldegree2 schooldegree, replace
label copy vocdegree2 vocdegree, replace

*** drop schoolgpa and renam schoolgpa_cum
drop schoolgpa
ren schoolgpa_cum schoolgpa

*** generate maximum educational attainment variables per age year (range: 10-75)
drop if agefy<10 // exclude observations for age<10
foreach var of varlist schooldegree schooldegree_abroad schooldegree_add schoolgpa vocdegree vocdegree_abroad vocdegree_add {
   bys ID_t agefy: egen `var'_a=max(`var')
   bys ID_t agefy: egen `var'_b=max(`var'), missing  
   replace `var'_a=`var'_b if `var'_a==.
   lab def `var' .o"out of empirical data range", modify
   lab val `var'_a `var'
   drop `var' `var'_b
   ren `var'_a `var'_
   }
lab var schooldegree_ "highest school-leaving degree"
lab var schooldegree_abroad_ "highest school-leaving degree obtained abroad"  
lab var schooldegree_add_ "new school-leaving degree obtained"
lab var schoolgpa_ "GPA highest school-leaving degree"
lab var vocdegree_ "highest vocational degree"
lab var vocdegree_abroad_ "highest vocational degree obtained abroad"  
lab var vocdegree_add_ "new vocational degree obtained"

*** transfer into wide format

* keep relevant observations, relevant variables and keep one row per month
bys ID_t agefy: gen n=_n
keep if n==1 // keep information from month when person enters new age (birthday month)
drop n month birthdate agem agey migration_age 

* reshape into wide format
qui sum agefy
local max=r(max)
reshape wide schooldegree_ schooldegree_abroad_ schooldegree_add_ schoolgpa_ vocdegree_ vocdegree_abroad_ vocdegree_add_, i(ID_t) j(agefy)
foreach var of varlist schooldegree_10- vocdegree_add_`max'{
   replace `var'=.o if `var'==.
   }

* label variables
foreach i of numlist 10/`max'{   
   lab var schooldegree_`i' "highest school leaving degree at age `i'"
   lab var schooldegree_abroad_`i' "highest school-leaving degree obtained abroad age `i'"
   lab var schooldegree_add_`i' "new school-leaving degree obtained at age `i'"
   lab var schoolgpa_`i' "GPA highest school-leaving degree at age `i'"
   lab var vocdegree_`i' "highest school leaving degree at age `i'"
   lab var vocdegree_abroad_`i' "highest school-leaving degree obtained abroad age `i'"
   lab var vocdegree_add_`i' "new school-leaving degree obtained at age `i'"  
   } 

* order variables
order ID_t lowage schooldegree_1_age vocdegree_1_age schooldegree_10-schooldegree_`max' schooldegree_abroad_10-schooldegree_abroad_`max' schooldegree_add_10-schooldegree_add_`max' schoolgpa_10-schoolgpa_`max' ///
      vocdegree_10-vocdegree_`max' vocdegree_abroad_10-vocdegree_abroad_`max' vocdegree_add_10-vocdegree_add_`max'  

* order variables
order _all, alphabetic
order ID_t lowage schooldegree_1_age vocdegree_1_age  
	  

*** SAVE DATA ******************************************************************
compress
save "${savedta}\educ_age.dta", replace	
exit

