********************************************************************************
* Merge information on school and vocational training trajectories    		   *
*      							                                               *    
* Steffen Schindler, 16/04/2025                               				   *
********************************************************************************

clear
set more off
cap log close

version 16.1

use "${savedta}\month_episodes", clear


*** merge information on year of birth
merge m:1 ID_t using "${savedta}\basicinfo.dta", nogen keep(1 3) keepusing(birthdate)

* generate age in months and in years
gen agem=month-birthdate
lab var agem "age in months"
gen agey=(month-birthdate)/12
lab var agey "age in years"

* generate indicator if respondent has spells with implausible age
gen temp=0
replace temp=1 if agey<6 & agey>=5.5
replace temp=2 if agey<5.5 & agey>=5
replace temp=3 if agey<5 & agey>=0
replace temp=4 if agey<0
bys ID_t: egen lowage=max(temp)
lab def lowage 0"only spells with age>=6" 1"spells with 5.5<=age<6" 2"spells with 5<=age<5.5" 3"spells with 0<=age<5" 4"spells with age<0" 
lab val lowage lowage
lab var lowage "respondent has spells with age<5.5"
bys ID_t: gen n=_n
ta lowage if n==1,m
drop temp* n


*** keep one line per month and drop unnecessary variables
keep if monthnr==1
drop splink sptype spms monthnr dur
sort ID_t month


*** merge information from school_recode
merge 1:1 ID_t month using "${savedta}\school_recode.dta", nogen keep(1 3) ///
keepusing(splink dur temp2 schooltype schooldegree schooldegree2 schooldegree_cum schooldegree_add schoolgpa ///
abifield1 abifield2 abifield3 abifield4 abifield5 fedschool gerschool recog schooldta)

* fill empty lines for schooldegree_cum 
sort ID_t month
replace schooldegree_cum=schooldegree_cum[_n-1] if schooldegree_cum==. & ID_t==ID_t[_n-1] // fill subsequent spells
gsort ID_t -month // sort months in decending order to fill oldest spells
replace schooldegree_cum=schooldegree_cum[_n-1] if schooldegree_cum==. & schooldegree_cum[_n-1]==0 & ID_t==ID_t[_n-1]
tab schooldegree_cum,m
gen temp1a=1 if schooldegree_cum==.
bys ID_t: egen temp1b=max(temp1a)
//list ID_t month agey schooltype schooldegree schooldegree2 schooldegree_cum fedschool schoolgpa temp2 if temp1b==1, sepby(ID_t)
bys ID_t: egen temp3a=max(schooldegree_cum) if temp1b==1 // mark highest value on schooldegree_cum if still missing values
bys ID_t: egen temp3b=max(schooldegree_cum) if temp3a==., missing // take into account missing values
tab temp3a temp3b if temp1b==1,m // values 8 (Haupt) and 12 (qual.Haupt) 
//list ID_t month agey schooltype schooldegree schooldegree2 schooldegree_cum fedschool schoolgpa temp2 if test1b==1 & temp3a<., sepby(ID_t)
replace schooldegree_cum=0 if temp3a==0 & schooldegree_cum==.
replace schooldegree_cum=0 if temp3a==8 & temp1b==1 & schooldegree_cum==. // set to no degree (GER)
replace schooldegree_cum=2 if temp3a==12 & temp1b==1 & schooldegree_cum==. // set to no degree or more (GER)
replace schooldegree_cum=.m if temp3a==. & temp3b==. & temp1b==1 & schooldegree_cum==. // no school information at all for these cases
lab def schooldegree2 .m "case without any schooldegree information", modify
tab schooldegree_cum,m
sort ID_t month

* restrict infos in degree variables to months when they apply
foreach var of varlist schooldegree schoolgpa abifield1 abifield2 abifield3 abifield4 abifield5 recog schooldegree2{
   replace `var'=. if temp2==.
   }
drop temp*


*** merge information from voctrain_recode
ren splink splink_school
ren dur dur_school
merge 1:1 ID_t month using "${savedta}\voctrain_recode.dta", nogen keep(1 3) ///
keepusing(splink dur temp2 migration_age gertrain fedtrain vocdegree_detail vocgpa voctype ///
vocdegree vocdegree2 vocdegree_cum vocdegree_add voctraindta)
ren splink splink_voctrain
ren dur dur_voctrain

* fill empty lines for vocdegree_cum 
sort ID_t month
clonevar test=vocdegree_cum
replace vocdegree_cum=vocdegree_cum[_n-1] if vocdegree_cum==. & ID_t==ID_t[_n-1] // fill subsequent spells
gsort ID_t -month // sort months in decending order to fill oldest spells
replace vocdegree_cum=vocdegree_cum[_n-1] if vocdegree_cum==. & vocdegree_cum[_n-1]==0 & ID_t==ID_t[_n-1]
tab vocdegree_cum,m
gen temp1a=1 if vocdegree_cum==.
bys ID_t: egen temp1b=max(temp1a)
//list ID_t month agey voctype vocdegree2 schooldegree_cum vocdegree_cum test if temp1b==1, sepby(ID_t)
bys ID_t: egen temp3a=max(vocdegree_cum) if temp1b==1 // mark highest value on vocdegree_cum if still missing values
bys ID_t: egen temp3b=max(vocdegree_cum) if temp3a==., missing // take into account missing values
tab temp3a temp3b if temp1b==1,m 
//list ID_t month agey voctype vocdegree2 schooldegree_cum vocdegree_cum test if temp1b==1 & temp3<., sepby(ID_t)
replace vocdegree_cum=.m if temp3a==. & temp3b==. & temp1b==1 & vocdegree_cum==. // no vocdegree information at all for these cases
lab def vocdegree2 .m "case without any vocdegree information", modify
replace vocdegree_cum=0 if vocdegree_cum==. & voctraindta==. & temp3a<. // set to no voc. degree (applies to early months only/when no infos in voctrain dta)
sort ID_t month

* restrict infos in degree variables to months when they apply
foreach var of varlist vocdegree_detail vocgpa vocdegree vocdegree2{
   replace `var'=. if temp2==.
   }
drop temp* test


*** expand information about age of migration to all lines
bys ID_t: egen temp1=max(migration_age)
bys ID_t: egen temp2=max(migration_age), missing
replace migration_age=temp1
replace migration_age=temp2 if migration_age==.
replace migration_age=.c if migration_age==.


*** Save data ******************************************************************
compress
save "${savedta}\educ_merge.dta", replace	

