********************************************************************************
* Income data plausibiliy checks and corrections                  	     	   *
*      							                                               *    
* Steffen Schindler, 16/04/2025                               				   *
********************************************************************************

clear
set more off
cap log close

version 16.1

use "${savedta}\SC6_spEmp_D_${SUF}.dta"


*** SAMPLE SELECTION ***********************************************************

*** merge information on interview dates from CohortProfile
merge m:1 ID_t wave using "${savedta}\SC6_CohortProfile_D_${SUF}.dta", nogen keep(match master) keepusing(tx80107 tx8600d tx8600m tx8600y)  
* recode date of interview into months since jan 1960 
gen intmonth = ym(tx8600y,tx8600m)
format intmonth %tm
lab var intmonth "month since 01/1960"
* month to which earnings information refer
gen earnmonth=intmonth-1
format earnmonth %tm
lab var earnmonth "earnings: month since 01/1960"

*** merge information on spells
merge m:m ID_t splink using "${savedta}\SC6_Biography_D_${SUF}.dta", nogen keep(match master) keepusing(sptype spms splast startm starty endm endy) 
* recode indicators of episode's start and end in YM format 
gen start = ym(starty,startm)
gen end = ym(endy,endm)
format start end %tm
lab var start "start in months since Jan 1960"
lab var end "end in months since Jan 1960"
* drop if month referring to earnings is outside episode
drop if (earnmonth<start | earnmonth>end) & start<=. & end<=.

*** exclude ALWA data (no information on gross earnings / data not comparable)
drop if wave==1


*** AUXILIARY VARIABLES ********************************************************

* adjust implausible recode of ts23511_g1 when first earnings filter variable ts23511==1 (less than 1500EUR) 
ta ts23511_g1 ts23512 if ts23511==1, m // if inlist(ts23512,.b,.c) --> cases were assigned to lowest category of ts23511_g1 (<500EUR)
replace ts23511_g1=2 if inlist(ts23512,.b,.c) & ts23511==1 // assign to intermediate category instead (500-1000EUR)
ta ts23511_g1 ts23512 if ts23511==1, m 

* generate metric GROSS earnings values from categories by assigning the mean values of the categories (when exact figures are absent)
gen gross_earn=ts23510 
lab val gross_earn enmiss
lab var gross_earn "gross monthly earnings"
tabstat gross_earn, by(ts23511_g1) stat(mean median) // check empirical means and medians within earnings categories
table wave ts23511_g1, c(mean gross_earn) format(%9.0f) // not much variation in mean values across waves
levelsof ts23511_g1, local(level)
foreach l of local level{
   sum gross_earn if ts23511_g1==`l' 
   replace gross_earn=r(mean) if gross_earn>=. & ts23511_g1==`l' // assign mean values from observations with metric earnings information
   }
replace gross_earn=floor(gross_earn)
tabstat gross_earn if ts23510>=., by(ts23511_g1) stat(mean median N)

* generate metric NET earnings values from categories by assigning the mean values of the categories (when exact figures are absent)
gen net_earn=ts23410 
lab val net_earn enmiss
lab var net_earn "net monthly earnings"
tabstat net_earn, by(ts23411_g1) stat(mean median) // check empirical means and medians within earnings categories
table wave ts23411_g1, c(mean net_earn) format(%9.0f) // not much variation in mean values across waves
levelsof ts23411_g1, local(level)
foreach l of local level{
   sum net_earn if ts23411_g1==`l' 
   replace net_earn=r(mean) if net_earn>=. & ts23411_g1==`l' // assign mean values from observations with metric earnings information
   }
replace net_earn=floor(net_earn)
tabstat net_earn if ts23410>=., by(ts23411_g1) stat(mean median N)

* generate row total of special payments
egen temp_boni=rowtotal(ts23541 ts23542 ts23543 ts23544 ts23545 ts23546)


*** SAMPLE CLEANING ************************************************************

*** check and remove duplicates 

* generate variable indicating number of parallel spell
bys ID_t wave (splink): gen n=_n
bys ID_t: egen nn=max(n) // indicator of maximum number of spells with waves

* generate variable counting overall number of spells per ID
bys ID_t (wave): gen count=_n 

* duplicates: same splink, GROSS earnings and actual working hours (based on open GROSS earnings categories) 
duplicates tag ID_t splink wave start end ts23510 ts23223_g1, gen(dup1g)
ta dup1g,m
bys ID_t: egen temp1g=max(dup1g) 
//list ID_t splink wave sptype start end intmonth earnmonth ts23510 ts23223_g1 n dup1g if temp1g>=1, sepby(ID_t) 
duplicates drop ID_t splink wave start end ts23510 ts23223_g1, force

* duplicates: same splink, NET earnings and actual working hours (based on open NET earnings categories) 
duplicates tag ID_t splink wave start end ts23410 ts23223_g1, gen(dup1n)
ta dup1n,m
bys ID_t: egen temp1=max(dup1n) 
//list ID_t splink wave sptype start end intmonth earnmonth ts23510 ts23223_g1 n dup1n if temp1n>=1, sepby(ID_t) 
duplicates drop ID_t splink wave start end ts23410 ts23223_g1, force

* duplicates: same splink, GROSS earnings and actual working hours (based on categorized GROSS earnings categories) 
duplicates tag ID_t splink wave start end ts23511_g1 ts23223_g1, gen(dup2g)
ta dup2g,m 
bys ID_t: egen temp2g=max(dup2g) 
//list ID_t splink wave sptype start end intmonth earnmonth ts23510 ts23223_g1 n dup2g if temp2g>=1, sepby(ID_t) 
duplicates drop ID_t splink wave start end ts23511_g1 ts23223_g1, force

* duplicates: same splink, NET earnings and actual working hours (based on categorized NET earnings categories) 
duplicates tag ID_t splink wave start end ts23411_g1 ts23223_g1, gen(dup2n)
ta dup2n,m 
bys ID_t: egen temp2n=max(dup2n) 
//list ID_t splink wave sptype start end intmonth earnmonth ts23510 ts23223_g1 n dup2n if temp2g>=1, sepby(ID_t) 
duplicates drop ID_t splink wave start end ts23411_g1 ts23223_g1, force

* duplicates: same GROSS earnings, NET earnings, starting date, actual working hours, special payments (based on open GROSS and NET earnings categories)  
duplicates tag ID_t wave ts23410 ts23510 start ts23223_g1 ts23541 ts23542 ts23543 ts23544 ts23545 ts23546, gen(dup3gn1)
ta dup3gn1,m 
bys ID_t: egen temp3gn1=max(dup3gn1) 
bys ID_t wave dup3gn1 (n): gen dupngn1=_n if dup3gn1>=1
//list ID_t splink wave sptype start end ts23410 ts23510 ts23223_g1 ts23541 ts23542 ts23543 ts23544 ts23545 ts23546 n dup3gn1 dupngn1 if temp3gn1>=1 & dupngn1<.,sepby(ID_t) 
duplicates drop ID_t wave ts23410 ts23510 start ts23223_g1 ts23541 ts23542 ts23543 ts23544 ts23545 ts23546, force

* duplicates: same GROSS earnings, NET earnings, actual working hours, special payments (based on open GROSS and NET earnings categories)  
duplicates tag ID_t wave ts23410 ts23510 ts23223_g1 ts23541 ts23542 ts23543 ts23544 ts23545 ts23546, gen(dup3gn2)
ta dup3gn2,m 
bys ID_t: egen temp3gn2=max(dup3gn2) 
bys ID_t wave dup3gn2 (n): gen dupngn2=_n if dup3gn2>=1
//list ID_t splink wave sptype start end ts23410 ts23510 ts23223_g1 ts23541 ts23542 ts23543 ts23544 ts23545 ts23546 n dup3gn2 dupngn2 if temp3gn2>=1 & dupngn2<.,sepby(ID_t) 
drop if dup3gn2>=1 & dupngn2>1 & dupngn2<. & (ts23541<. | ts23542<. | ts23543<. | ts23544<. | ts23545<. | ts23546<.) // drop if at least 1 bonus non-missing
drop if dup3gn2>=1 & dupngn2>1 & dupngn2<. & ts23223_g1>30 & ts23223_g1<.  // drop duplicates if working hours >30h
drop if dup3gn2>=1 & dupngn2>1 & dupngn2<. & ts23223_g1==0                 // drop duplicates if working hours =0h
drop if dup3gn2>=1 & dupngn2>1 & dupngn2<. & ts23510==0                    // drop duplicates if earnings =0EUR
drop if dup3gn2>1                                                          // drop if more than two parallel spells 

* duplicates: same GROSS earnings, actual working hours, special payments (based on open GROSS earnings categories)  
duplicates tag ID_t wave ts23510 ts23223_g1 ts23541 ts23542 ts23543 ts23544 ts23545 ts23546, gen(dup3g)
ta dup3g,m 
bys ID_t: egen temp3g=max(dup3g) 
bys ID_t wave dup3g (n): gen dupng=_n if dup3g>=1
//list ID_t splink wave sptype start end ts23410 ts23510 ts23223_g1 ts23541 ts23542 ts23543 ts23544 ts23545 ts23546 n dup3g dupng if temp3g>=1 & dupng<.,sepby(ID_t) 
drop if dup3g>=1 & dupng>1 & dupng<. & (ts23541<. | ts23542<. | ts23543<. | ts23544<. | ts23545<. | ts23546<.) // drop if at least 1 bonus non-missing
drop if dup3g>=1 & dupng>1 & dupng<. & ts23223_g1>30 & ts23223_g1<. // drop duplicates if working hours >30h
drop if dup3g>=1 & dupng>1 & dupng<. & ts23223_g1==0                // drop duplicates if working hours =0h
drop if dup3g>=1 & dupng>1 & dupng<. & ts23510==0                   // drop duplicates if earnings =0EUR
drop if dup3g>1                                                     // drop if more than two parallel spells 

* duplicates: same NET earnings, actual working hours, special payments (based on open NET earnings categories)  
duplicates tag ID_t wave ts23410 ts23223_g1 ts23541 ts23542 ts23543 ts23544 ts23545 ts23546, gen(dup3n)
ta dup3n,m 
bys ID_t: egen temp3n=max(dup3n) 
bys ID_t wave dup3n (n): gen dupnn=_n if dup3n>=1
//list ID_t splink wave sptype start end ts23410 ts23510 ts23223_g1 ts23541 ts23542 ts23543 ts23544 ts23545 ts23546 n dup3n dupnn if temp3n>=1 & dupnn<.,sepby(ID_t) 
// --> do not drop cases based on same NET earnings when different or missing gross earnings

* update variable indicating number of parallel spells
drop n nn
bys ID_t wave (splink): gen n=_n
bys ID_t: egen nn=max(n)          // max number of parallel spells per ID 
bys ID_t wave (splink): gen p=_N  // number of parallel spells per wave 

* identify parallel spells with unusually high combined gross earnings values or working hours 
bys ID_t wave (splink): egen temp4_total=total(gross_earn)     // temp4_total: total earnings per wave
replace temp4_total=. if temp4_total==0
bys ID_t n: egen temp4_a=mean(temp4_total) if n==1             // temp4_mean: mean earnings across all waves 
bys ID_t: egen temp4_mean=max(temp4_a)
bys ID_t n: egen temp4_b=median(temp4_total) if n==1           // temp4_med: median earnings across all waves 
bys ID_t: egen temp4_med=max(temp4_b)
gen temp4_relmean=temp4_total/temp4_mean                       // temp4_relmean: earnings as relative value to mean earnings across all waves 
gen temp4_relmed=temp4_total/temp4_med                         // temp4_relmed: earnings as relative value to median earnings across all waves 
sort ID_t wave (splink)
gen temp4_c=temp4_total
replace temp4_c=temp4_c[_n-1] if ID_t==ID_t[_n-1] & temp4_c>=. // fill gaps with earnings of previous spell
sort ID_t n wave
gen temp4_d=temp4_c/temp4_c[_n-1] if ID_t==ID_t[_n-1] & n==1   // temp4_relchange1: earnings as relative change to earnings in previous spell
bys ID_t wave (splink): egen temp4_relchange1=max(temp4_d)
replace temp4_relchange1=0 if wave==2 & temp4_relchange1>=.
gsort ID_t -wave
gen temp4_e=temp4_total 
replace temp4_e=temp4_e[_n-1] if ID_t==ID_t[_n-1] & temp4_e>=. // fill gaps with earnings of subsequent spell
gsort ID_t n -wave
gen temp4_f=temp4_e[_n-1]/temp4_e if ID_t==ID_t[_n-1] & n==1   // temp4_relchange2: earnings as relative change to earnings in subsequent spell
bys ID_t wave (splink): egen temp4_relchange2=max(temp4_f)
replace temp4_relchange2=0 if wave==2 & temp4_relchange2>=.
bys ID_t wave (splink): egen temp4_wh=total(ts23223_g1)        // temp4_wh: total working hours per wave
bys ID_t n: egen temp4_g=mean(temp4_wh) if n==1                // temp4_meanwh: mean earnings across all waves 
bys ID_t: egen temp4_meanwh=max(temp4_g)                       
gen temp4_relmeanwh=temp4_wh/temp4_meanwh                      // temp4_relavrg: earnings as relative value to mean earnings across all waves 
sort ID_t wave splink

* edit cases with unusually high working hours
gen temp5a=1 if temp4_wh>80 & p>1 // tag variables with total working hours per month>80 if multiple spells per wave 
bys ID_t: egen temp5a_tag=max(temp5a)
ta temp5a_tag if count==1
//list ID_t wave splink n p start end gross_earn temp4_total ts23541 ts23542 ts23543 ts23544 ts23545 ts23546 ts23223_g1 temp4_wh temp5a if temp5a_tag==1 & nn>1, sepby(ID_t) nol
gen temp5b=ts23223_g1 if temp5a!=1                             // variable indicating working hours except cases with unusually high values 
bys ID_t splink (wave): gen temp5_n=_N                         // generate number of waves per splink
bys ID_t splink (wave): egen temp5_mean=mean(temp5b)           // generate mean per splink (except line with outlier)
bys ID_t splink (wave): egen temp5_med=median(temp5b)          // generate median per splink (except line with outlier)
bys ID_t splink (wave): egen temp5_max=max(temp5b)             // generate maximum per splink (except line with outlier)
gen temp5_mean_rel=ts23223_g1/temp5_mean if temp5a==1          // value of outlier relative to mean of rest of splink
gen temp5_med_rel=ts23223_g1/temp5_med if temp5a==1            // value of outlier relative to median of rest of splink
gen temp5_max_rel=ts23223_g1/temp5_max if temp5a==1            // value of outlier relative to max of rest of splink
//list ID_t wave splink n p start end ts23510 temp4_total ts23223_g1 temp4_wh temp5a temp6a temp6_n temp6_mean temp6_mean_rel temp6_med temp6_med_rel temp6_max temp6_max_rel if temp5a_tag==1 & nn>1, sepby(ID_t) nol
replace ts23223_g1=.l if (temp5_mean_rel>=2 & temp5_mean_rel<.) | (temp5_med_rel>=2 & temp5_med_rel<.) | (temp5_max_rel>=2 & temp5_max_rel<.)  // set to missing if outlier deviates by factor 2
cap drop temp4_wh temp5a temp5a_tag                            // update indicators
bys ID_t wave (splink): egen temp4_wh=total(ts23223_g1)  
gen temp5a=1 if temp4_wh>80 & p>1 
bys ID_t: egen temp5a_tag=max(temp5a)
ta temp5a_tag if count==1
//list ID_t wave splink tx8600m tx8600y n p start end ts23410 net_earn ts23510 gross_earn temp4_total ts23541 ts23542 ts23543 ts23544 ts23545 ts23546 ts23223_g1 temp4_wh temp5a if temp5a_tag==1 & nn>1, sepby(ID_t) nol
replace ts23223_g1=.l if ID_t==8000974 & wave==4 & splink==260006   // most likely error in working hours
drop if ID_t==8001063 & wave==3 & splink==260004                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8001185 & wave==4 & splink==260005   // most likely error in working hours
replace ts23223_g1=.l if ID_t==8001390 & wave==5 & splink==260012   // most likely error in working hours
replace ts23223_g1=.l if ID_t==8001548 & wave==10                   // most likely error in working hours
drop if ID_t==8001549 & wave==3 & splink==260001                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8001913 & wave==4 & splink==260002   // most likely error in working hours
replace ts23223_g1=.l if ID_t==8002250 & wave==8 & splink==260005   // most likely error in working hours
drop if ID_t==8002264 & wave==3 & inrange(splink,260011,260013)     // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8002444 & wave==3 & splink==260004   // most likely error in working hours
replace ts23223_g1=.l if ID_t==8002574 & wave==5 & splink==260002   // most likely error in working hours
drop if ID_t==8002695 & wave==2 & inlist(splink,260005,260006)      // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8002902 & wave==2 & splink==260004   // most likely error in working hours
drop if ID_t==8003012 & wave==11 & splink==260006                   // most likely multiple reports of the same episode with recall errors
drop if ID_t==8003094 & wave==3 & splink==260006                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8003107 & wave==7 & splink==260002   // most likely error in working hours
replace ts23223_g1=.l if ID_t==8003137 & wave==3 & splink==260002   // most likely error in working hours
drop if ID_t==8003212 & wave==8 & splink==260008                    // spell duration only 1 month
drop if ID_t==8003285 & wave==4 & splink==260005                    // most likely multiple reports of the same episode with recall errors
replace ts23511_g1=.l if ID_t==8003293 & wave==6 & splink==260005   // most likely wrong values for parallel episode (repetition of values from first spell)
replace ts23510=.l if ID_t==8003293 & wave==6 & splink==260005      // 
replace ts23411_g1=.l if ID_t==8003293 & wave==6 & splink==260005   // 
replace ts23410=.l if ID_t==8003293 & wave==6 & splink==260005      // 
replace ts23223_g1=.l if ID_t==8003293 & wave==6 & splink==260005   // 
replace ts23223_g1=.l if ID_t==8004248 & wave==2 & splink==260004   // most likely error in working hours 
replace ts23223_g1=.l if ID_t==8004329 & wave==4                    // most likely error in working hours 
drop if ID_t==8004646 & wave==3 & splink==260008                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8004945 & wave==12 & splink==260007  // most likely error in working hours
replace ts23223_g1=.l if ID_t==8004983 & wave==3 & splink==260003   // most likely error in working hours
replace ts23511_g1=.l if ID_t==8004989 & wave==8 & splink==260010   // most likely multiple reports of the same episode with recall errors
replace ts23511_g1=.l if ID_t==8005036 & wave==6 & splink==260005   // most likely multiple reports of the same episode with recall errors
drop if ID_t==8005480 & wave==6 & splink==260008                    // most likely multiple reports of the same episode with recall errors
drop if ID_t==8005890 & wave==3 & splink==260003                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8006271 & wave==3 & splink==260006   // most likely error in working hours 
drop if ID_t==8006455 & wave==3 & splink==260005                    // spell duration only 1 month
drop if ID_t==8006583 & wave==4 & splink==260010                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8006618 & wave==3 & splink==260014   // most likely error in working hours 
replace ts23223_g1=.l if ID_t==8006837 & wave==2 & splink==260011   // most likely error in working hours 
drop if ID_t==8007049 & wave==2 & splink==260003                    // most likely multiple reports of the same episode with recall errors
drop if ID_t==8007518 & inlist(wave,2,3) & splink==260003           // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8007554 & wave==5 & splink==260012   // most likely error in working hours 
drop if ID_t==8007696 & wave==4 & splink==260006                    // most likely multiple reports of the same episode with recall errors
drop if ID_t==8008056 & wave==2 & splink==260001                    // most likely multiple reports of the same episode with recall errors
drop if ID_t==8008074 & wave==3 & splink==260004                    // most likely multiple reports of the same episode with recall errors
replace ts23511_g1=.l if ID_t==8008107 & wave==3 & splink==260002   // most likely wrong values for parallel episode (repetition of values from first spell)
drop if ID_t==8008136 & wave==3 & splink==260009                    // most likely multiple reports of the same episode with recall errors
drop if ID_t==8008714 & wave==3 & splink==260008                    // most likely multiple reports of the same episode with recall errors
drop if ID_t==8008946 & wave==2 & splink==260006                    // most likely multiple reports of the same episode with recall errors
drop if ID_t==8009057 & wave==2 & splink==260006                    // most likely multiple reports of the same episode with recall errors
drop if ID_t==8009071 & wave==3 & inlist(splink,260001,260002)      // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8009403 & wave==2 & splink==260002   // most likely error in working hours 
drop if ID_t==8009714 & wave==8 & splink==260005                    // spell duration only 1 month
replace ts23223_g1=.l if ID_t==8009884 & wave==4 & splink==260005   // most likely error in working hours 
drop if ID_t==8009988 & wave==3 & splink==260009                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8010031 & wave==6 & splink==260004   // most likely error in working hours  starty
replace ts23223_g1=.l if ID_t==8010140 & wave==7 & splink==260002   // most likely error in working hours 
drop if ID_t==8010200 & wave==2 & splink==260011                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8010200 & wave==2                    // most likely error in working hours 
drop if ID_t==8010203 & wave==2 & splink==260003                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8010267 & wave==11 & splink==260021  // most likely error in working hours 
replace ts23223_g1=.l if ID_t==8010407 & wave==12 & splink==260008  // most likely error in working hours
drop if ID_t==8010788 & wave==2 & splink==260003                    // most likely multiple reports of the same episode with recall errors
drop if ID_t==8010788 & wave==3 & splink==260003                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8010874 & wave==8 & splink==260005   // most likely error in working hours
replace ts23223_g1=.l if ID_t==8010874 & wave==10 & splink==260005  // most likely error in working hours
drop if ID_t==8011308 & wave==2 & splink==260002                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8011308 & wave==3 & splink==260002   // most likely error in working hours
drop if ID_t==8011550 & wave==2 & splink==260004                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8011770 & temp5a==1                  // total working hours implausible
drop if ID_t==8011948 & wave==2 & splink==260001                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8011948 & temp5a==1                  // total working hours implausible
drop if ID_t==8012038 & wave==4 & splink==260009                    // most likely multiple reports of the same episode with recall errors
drop if ID_t==8012115 & wave==9 & splink==260008                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8012316 & wave==8 & splink==260006   // most likely error in working hours
drop if ID_t==8012354 & wave==3 & inlist(splink,260001,260002)      // most likely multiple reports of the same episode with recall errors
drop if ID_t==8012379 & wave==7 & splink==260019                    // spell duration only 1 month
replace ts23223_g1=.l if ID_t==8012443 & wave==12 & splink==260008  // most likely error in working hours
drop if ID_t==8012625 & wave==2 & splink==260008                    // most likely multiple reports of the same episode with recall errors
drop if ID_t==8012671 & wave==2 & splink==260003                    // most likely multiple reports of the same episode with recall errors
drop if ID_t==8012671 & wave==3 & splink==260003                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8012712 & wave==5 & splink==260008   // most likely error in working hours
drop if ID_t==8012743 & wave==3 & splink==260005                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8012743 & wave==3 & splink==260007   // most likely error in working hours
drop if ID_t==8012748 & wave==3 & splink==260005                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8013247 & wave==5 & splink==260002   // most likely error in working hours
replace ts23223_g1=.l if ID_t==8015189 & wave==3 & splink==260006   // most likely error in working hours
drop if ID_t==8020321 & wave==4 & splink==260002                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8020419 & wave==6 & splink==260005   // most likely error in working hours
replace ts23223_g1=.l if ID_t==8020419 & wave==7 & splink==260005   // most likely error in working hours
drop if ID_t==8020461 & wave==7 & splink==260002                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8021225 & wave==8 & splink==260003   // most likely error in working hours
drop if ID_t==8021277 & wave==5 & splink==260006                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8021300 & wave==13 & splink==260004  // most likely error in working hours
drop if ID_t==8021747 & wave==7 & splink==260006                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8021772 & wave==6 & splink==260007   // most likely error in working hours
drop if ID_t==8022523 & wave==5 & splink==260005                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8022592 & wave==6 & splink==260004   // most likely error in working hours
replace ts23223_g1=.l if ID_t==8022722 & wave==4 & splink==260003   // most likely error in working hours
drop if ID_t==8024330 & wave==5 & splink==260004                    // most likely multiple reports of the same episode with recall errors
replace ts23223_g1=.l if ID_t==8024431 & wave==11 & splink==260009  // most likely error in working hours
replace ts23223_g1=.l if ID_t==8024431 & wave==12 & splink==260009  // most likely error in working hours
replace ts23511_g1=.l if ID_t==8024853 & wave==9 & splink==260005   // most likely wrong values for parallel episode (repetition of values from first spell)
replace ts23510=.l if ID_t==8024853 & wave==9 & splink==260005      // 
replace ts23411_g1=.l if ID_t==8024853 & wave==9 & splink==260005   // 
replace ts23410=.l if ID_t==8024853 & wave==9 & splink==260005      // 
replace ts23223_g1=.l if ID_t==8024853 & wave==9 & splink==260005   // 

* edit cases with zero earnings
gen temp6a=1 if net_earn==0 | gross_earn==0 // tag cases with zero net or gross earnings
bys ID_t: egen temp6a_tag=max(temp6a)
ta temp6a_tag if count==1
//list ID_t wave splink tx8600m tx8600y n p start end ts23410 net_earn ts23510 gross_earn temp4_total ts23541 ts23542 ts23543 ts23544 ts23545 ts23546 ts23223_g1 temp4_wh temp5a if temp6a_tag==1, sepby(ID_t) nol
drop if net_earn==0 & gross_earn==0 & ts23223_g1==0 & temp_boni==0  // drop if no income and no working hours
replace ts23410=.l if net_earn==0 & ts23223_g1!=0                   // set to missing if zero net earnings and other than zero working hours
replace ts23411_g1=.l if net_earn==0 & ts23223_g1!=0                //
replace net_earn=.l if net_earn==0 & ts23223_g1!=0                  //
replace ts23510=.l if gross_earn==0 & ts23223_g1!=0                 // set to missing if zero gross earnings and other than zero working hours
replace ts23511_g1=.l if gross_earn==0 & ts23223_g1!=0              //
replace gross_earn=.l if gross_earn==0 & ts23223_g1!=0              //

* update variable indicating number of parallel spell
drop n nn p
bys ID_t wave (splink): gen n=_n
bys ID_t: egen nn=max(n)          // max number of parallel spells per ID 
bys ID_t wave (splink): gen p=_N  // number of parallel spells per wave 

* update variables indicating parallel spells with unusually high combined earnings values or working hours 
cap drop temp4*
gen temp4g_h=gross_earn/ts23223_g1                                 // temp4g_h: hourly gross earnings
bys ID_t: egen temp4g_hmean=mean(temp4g_h)                         // temp4g_hmean: mean hourly gross earnings
gen temp4g_relhmean=temp4g_h/temp4g_hmean                          // temp4g_relhmean: hourly earnings relative to mean hourly earnings across all waves
bys ID_t wave (splink): egen temp4g_total=total(gross_earn)        // temp4g_total: total gross earnings per wave
replace temp4g_total=. if temp4g_total==0
bys ID_t n: egen temp4g_a=mean(temp4g_total) if n==1               // temp4g_mean: mean gross earnings across all waves 
bys ID_t: egen temp4g_mean=max(temp4g_a)
bys ID_t n: egen temp4g_b=median(temp4g_total) if n==1             // temp4g_med: median gross earnings across all waves 
bys ID_t: egen temp4g_med=max(temp4g_b)
gen temp4g_relmean=temp4g_total/temp4g_mean                        // temp4g_relmean: gross earnings as relative value to mean earnings across all waves 
gen temp4g_relmed=temp4g_total/temp4g_med                          // temp4g_relmed: gross earnings as relative value to median earnings across all waves 
sort ID_t wave (splink)
gen temp4g_c=temp4g_total
replace temp4g_c=temp4g_c[_n-1] if ID_t==ID_t[_n-1] & temp4g_c>=.  // fill gaps with gross earnings of previous spell
sort ID_t n wave
gen temp4g_d=temp4g_c/temp4g_c[_n-1] if ID_t==ID_t[_n-1] & n==1    // temp4g_relchange1: gross earnings as relative change to earnings in previous spell
bys ID_t wave (splink): egen temp4g_relchange1=max(temp4g_d)
replace temp4g_relchange1=0 if wave==2 & temp4g_relchange1>=.
gsort ID_t -wave
gen temp4g_e=temp4g_total 
replace temp4g_e=temp4g_e[_n-1] if ID_t==ID_t[_n-1] & temp4g_e>=.  // fill gaps with gross earnings of subsequent spell
gsort ID_t n -wave
gen temp4g_f=temp4g_e[_n-1]/temp4g_e if ID_t==ID_t[_n-1] & n==1    // temp4g_relchange2: gross earnings as relative change to earnings in subsequent spell
bys ID_t wave (splink): egen temp4g_relchange2=max(temp4g_f)
replace temp4g_relchange2=0 if wave==2 & temp4g_relchange2>=.
gen temp4n_h=net_earn/ts23223_g1                                   // temp4n_h: hourly net earnings
bys ID_t: egen temp4n_hmean=mean(temp4n_h)                         // temp4n_hmean: mean hourly net earnings
gen temp4n_relhmean=temp4n_h/temp4n_hmean                          // temp4n_relhmean: hourly earnings relative to mean hourly earnings across all waves
bys ID_t wave (splink): egen temp4n_total=total(net_earn)          // temp4n_total: total net earnings per wave
replace temp4n_total=. if temp4n_total==0
bys ID_t n: egen temp4n_a=mean(temp4n_total) if n==1               // temp4n_mean: mean net earnings across all waves 
bys ID_t: egen temp4n_mean=max(temp4n_a)
bys ID_t n: egen temp4n_b=median(temp4n_total) if n==1             // temp4n_med: median net earnings across all waves 
bys ID_t: egen temp4n_med=max(temp4n_b)
gen temp4n_relmean=temp4n_total/temp4n_mean                        // temp4n_relmean: net earnings as relative value to mean earnings across all waves 
gen temp4n_relmed=temp4n_total/temp4n_med                          // temp4n_relmed: net earnings as relative value to median earnings across all waves 
sort ID_t wave (splink)
gen temp4n_c=temp4n_total
replace temp4n_c=temp4n_c[_n-1] if ID_t==ID_t[_n-1] & temp4n_c>=.  // fill gaps with net earnings of previous spell
sort ID_t n wave
gen temp4n_d=temp4n_c/temp4n_c[_n-1] if ID_t==ID_t[_n-1] & n==1    // temp4n_relchange1: net earnings as relative change to earnings in previous spell
bys ID_t wave (splink): egen temp4n_relchange1=max(temp4n_d)
replace temp4n_relchange1=0 if wave==2 & temp4n_relchange1>=.
gsort ID_t -wave
gen temp4n_e=temp4n_total 
replace temp4n_e=temp4n_e[_n-1] if ID_t==ID_t[_n-1] & temp4n_e>=.  // fill gaps with net earnings of subsequent spell
gsort ID_t n -wave
gen temp4n_f=temp4n_e[_n-1]/temp4n_e if ID_t==ID_t[_n-1] & n==1    // temp4n_relchange2: net earnings as relative change to earnings in subsequent spell
bys ID_t wave (splink): egen temp4n_relchange2=max(temp4n_f)
replace temp4n_relchange2=0 if wave==2 & temp4n_relchange2>=.
bys ID_t wave (splink): egen temp4_wh=total(ts23223_g1)            // temp4_wh: total working hours per wave
sort ID_t wave splink

* edit cases with unusually high earnings
gen temp7a=1 if (temp4g_relmean>2 & temp4g_relmean<. & ((temp4g_relchange1>2 & temp4g_relchange1<.) | (temp4g_relchange2>2 & temp4g_relchange2<.))) | (temp4n_relmean>2 & temp4n_relmean<. & ((temp4n_relchange1>2 & temp4n_relchange1<.)|(temp4n_relchange2>2 & temp4n_relchange2<.)))  // tag variables with outliers compared to mean and previous earnings (treshold: factor 2)
bys ID_t: egen temp7a_tag=max(temp7a)
ta temp7a_tag if count==1
//list ID_t wave splink n p start end ts23410 net_earn temp4n_h temp4n_total temp4n_relmean temp4n_relhmean temp4n_relchange1 ts23510 gross_earn temp4g_h temp4g_total temp4g_relmean temp4g_relhmean temp4g_relchange1 ts23223_g1 temp4_wh temp7a if temp7a_tag==1, sepby(ID_t) nol
replace ts23410=.l if temp7a==1 & temp4n_relhmean>2 & temp4n_relhmean<.      // set to missing if net earnings outlier (threshold: factor 2)
replace ts23411_g1=.l if temp7a==1 & temp4n_relhmean>2 & temp4n_relhmean<.   //
replace net_earn=.l if temp7a==1 & temp4n_relhmean>2 & temp4n_relhmean<.     //
replace ts23510=.l if temp7a==1 & temp4g_relhmean>2 & temp4g_relhmean<.      // set to missing if gross earnings outlier
replace ts23511_g1=.l if temp7a==1 & temp4g_relhmean>2 & temp4g_relhmean<.   //
replace gross_earn=.l if temp7a==1 & temp4g_relhmean>2 & temp4g_relhmean<.   //

* edit when implausible relation between net and gross earnings
bys ID_t wave (splink): egen temp4b_total=total(temp_boni)                   // temp4b_total: total special payments (boni) per wave
gen temp4gb_total=temp4g_total+(temp4b_total/12)                             // temp4gb_total: monthly gross total per wave incl. special payments per month
gen temp4gb_row=gross_earn+(temp_boni/12)                                    // temp4gb_row: gross earnings per row incl. special payments per month
bys ID_t splink: egen temp4gb_smean=mean(temp4gb_row)                        // temp4gb_smean: mean gross earnings per spell incl. boni per month
gen temp4gb_srel=temp4gb_row/temp4gb_smean                                   // temp4gb_srel: gross earnings incl. boni ralative to average over all rows
gen temp4gb_srel2=1/temp4gb_srel                                             // temp4gb_srel2: inverse of temp4gb_srel
bys ID_t splink: egen temp4n_smean=mean(net_earn)                            // temp4n_smean: mean net earnings over all rows
gen temp4n_srel=net_earn/temp4n_smean                                        // temp4n_srel: net earnings ralative to average over all rows
gen temp4n_srel2=1/temp4n_srel                                               // temp4n_srel2: inverse of temp4n_srel
gen temp4ng_trel=temp4n_total/temp4gb_total                                  // temp4ng_trel: relation between net and gross earnings per wave
gen temp4ng_srel=net_earn/temp4gb_row                                        // temp4ng_srel: relation between net and gross earnings per row
recode temp4ng_trel (0=0 "0 net") (0.01/.30=1 "<30") (.30/.50=2 "<50") (.50/.99=3 "50+") (.99/1.01=4 "100") (1.01/max=5 ">100") (.=.), into(temp8a)
ta temp8a,m 
recode temp4ng_srel (0=0 "0 net") (0.01/.30=1 "<30") (.30/.50=2 "<50") (.50/.99=3 "50+") (.99/1.01=4 "100") (1.01/max=5 ">100") (.=.), into(temp8b)
ta temp8b,m 
gen temp8b_5=1 if temp8b==5 // --- cases when net earnings are higher than gross earnings ----------------------------------------------------------
bys ID_t: egen temp8bb_5=max(temp8b_5)
//list ID_t wave splink n p start end ts23410 net_earn ts23411_g1 ts23510 gross_earn ts23511_g1 temp_boni temp4ng_srel temp4n_total temp4g_total temp4b_total temp4gb_total temp8b_5 temp4n_srel temp4n_srel2 temp4gb_srel temp4gb_srel2 if temp8bb_5==1, sepby(ID_t) nol
replace net_earn=.l if temp8b_5==1 & ts23410>=. & ts23510<.    // set net estimates based on categories to missing when exact info on gross earnings exists
replace gross_earn=.l if temp8b_5==1 & ts23510>=. & ts23410<.  // set gross estimates based on categories to missing when exact info on net earnings esists
egen temp8c=rowmax(temp4n_srel temp4n_srel2 temp4gb_srel temp4gb_srel2) // indicator of maximum outlier value
replace net_earn=.l if temp8b_5==1 & ((ts23510>=. & ts23410>=.)|(ts23510<. & ts23410<.)) & (temp4n_srel==temp8c | temp4n_srel2==temp8c) // set net estimate to missing if it is more of an outlier than the gross estimate (when only one line per spell: both net and gross values will be set to missing)
replace ts23410=.l if temp8b_5==1 & ts23510<. & ts23410<. & (temp4n_srel==temp8c | temp4n_srel2==temp8c) // set net earnings to missing if it is more of an outlier than the gross estimate (when only one line per spell: both net and gross values will be set to missing)
replace gross_earn=.l if temp8b_5==1 & ((ts23510>=. & ts23410>=.)|(ts23510<. & ts23410<.)) & (temp4gb_srel==temp8c | temp4gb_srel2==temp8c) // set gross estimate to missing if it is more of an outlier than the net estimate (when only one line per spell: both net and gross values will be set to missing)
replace ts23510=.l if temp8b_5==1 & ts23510<. & ts23410<. & (temp4gb_srel==temp8c | temp4gb_srel2==temp8c) // set gross earnings to missing if it is more of an outlier than the net estimate (when only one line per spell: both net and gross values will be set to missing)
gen temp4ng_cat1=1 if ts23411_g1>ts23511_g1 & inrange(ts23411_g1,1,9) & inrange(ts23511_g1,1,9) // indicator if net category is higher than gross category
bys ID_t: egen temp4ng_cat2=max(temp4ng_cat1) 
ta temp4ng_cat1,m  // 316 cases with implausible information (net categories are higher than gross categories)
//list ID_t wave splink n p start end ts23410 net_earn ts23411_g1 ts23510 gross_earn ts23511_g1 temp_boni temp4ng_srel temp4ng_trel temp4ng_cat1 temp4n_srel temp4n_srel2 temp4gb_srel temp4gb_srel2 if temp4ng_cat2==1, sepby(ID_t) nol
replace ts23411_g1=.l if temp4ng_cat1==1 & ts23410>=. & ts23510<. // set net estimates based on categories to missing if exact info on gross earnings exists
replace ts23511_g1=.l if temp4ng_cat1==1 & ts23510>=. & ts23410<. // set gross estimates based on categories to missing if exact info on net earnings esists
replace ts23411_g1=.l if temp4ng_cat1==1 & ts23510>=. & ts23410>=. & (temp4n_srel==temp8c | temp4n_srel2==temp8c) // set net estimate to missing if it is more of an outlier than the gross estimate (when only one line per spell: both net and gross values will be set to missing)
replace ts23511_g1=.l if temp4ng_cat1==1 & ts23510>=. & ts23410>=. & (temp4gb_srel==temp8c | temp4gb_srel2==temp8c) // set gross estimate to missing if it is more of an outlier than the net estimate (when only one line per spell: both net and gross values will be set to missing)
ta temp8b,m 
gen temp8b_1=1 if temp8b==1 // --- cases when net earnings are less than 30 percent of gross earnings -----------------------------------------------
bys ID_t: egen temp8bb_1=max(temp8b_1)
sort ID_t wave splink
//list ID_t wave splink n p start end ts23410 ts23411_g1 net_earn ts23510 ts23511_g1 gross_earn temp_boni temp4ng_trel temp8b_1 temp4n_srel temp4n_srel2 temp4gb_srel temp4gb_srel2 if temp8bb_1==1, sepby(ID_t) nol
replace net_earn=.l if temp8b_1==1 & ts23410>=. & ts23510<.    // set net estimates based on categories to missing when exact info on gross earnings exists
replace gross_earn=.l if temp8b_1==1 & ts23510>=. & ts23410<.  // set gross estimates based on categories to missing when exact info on net earnings esists
replace net_earn=.l if temp8b_1==1 & ((ts23510>=. & ts23410>=.)|(ts23510<. & ts23410<.)) & (temp4n_srel==temp8c | temp4n_srel2==temp8c) // set net estimate to missing if it is more of an outlier than the gross estimate (when only one line per spell: both net and gross values will be set to missing)
replace ts23410=.l if temp8b_1==1 & ts23510<. & ts23410<. & (temp4n_srel==temp8c | temp4n_srel2==temp8c) // set net earnings to missing if it is more of an outlier than the gross estimate (when only one line per spell: both net and gross values will be set to missing)
replace gross_earn=.l if temp8b_1==1 & ((ts23510>=. & ts23410>=.)|(ts23510<. & ts23410<.)) & (temp4gb_srel==temp8c | temp4gb_srel2==temp8c) // set gross estimate to missing if it is more of an outlier than the net estimate (when only one line per spell: both net and gross values will be set to missing)
replace ts23510=.l if temp8b_1==1 & ts23510<. & ts23410<. & (temp4gb_srel==temp8c | temp4gb_srel2==temp8c) // set gross earnings to missing if it is more of an outlier than the net estimate (when only one line per spell: both net and gross values will be set to missing) 
 

*** Save data ******************************************************************
drop temp* dup*
compress
save "${savedta}\income_plausi.dta", replace	
exit
